@@ -239,10 +239,10 @@ qx.Class.define("callbackery.ui.Login", {
             }
             this.__ensureIframe();
             if (urlCfg.app === 'registration' && this.__registrationBtn){
-                this.__registrationBtn.fireEvent('tap',qx.event.type.Tap);
+                this.__registrationBtn.fireEvent('tap');
             }
             else if (urlCfg.app === 'passwordreset' && this.__passwordresetBtn){
-                this.__passwordresetBtn.fireEvent('tap',qx.event.type.Tap);
+                this.__passwordresetBtn.fireEvent('tap');
             }
         },this);
     },
